@@ -3,7 +3,7 @@
 /**
  * Driver for holidays in Japanese
  *
- * PHP Version 4
+ * PHP Version 5
  *
  * Copyright (c) 1997-2008 The PHP Group
  *
@@ -19,7 +19,7 @@
  * @package  Date_Holidays
  * @author   Hideyuki Shimooka <shimooka@doyouphp.jp>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Japan.php 277166 2009-03-14 21:31:51Z kguest $
+ * @version  CVS: $Id$
  * @link     http://pear.php.net/package/Date_Holidays
  * @see      http://www.h3.dion.ne.jp/~sakatsu/holiday_topic.htm
  */
@@ -93,7 +93,7 @@ define('DATE_HOLIDAYS_AUTUMNAL_EQUINOX_PARAM_2150', 24.2488);
  * @subpackage Driver
  * @author     Hideyuki Shimooka <shimooka@doyouphp.jp>
  * @license    http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version    CVS: $Id: Japan.php 277166 2009-03-14 21:31:51Z kguest $
+ * @version    CVS: $Id$
  * @link       http://pear.php.net/package/Date_Holidays
  * @see        http://www.h3.dion.ne.jp/~sakatsu/holiday_topic.htm
  */
@@ -129,7 +129,7 @@ class Date_Holidays_Driver_Japan extends Date_Holidays_Driver
      *
      * @access   protected
      */
-    function Date_Holidays_Driver_Japan()
+    public function __construct()
     {
     }
 
@@ -155,6 +155,7 @@ class Date_Holidays_Driver_Japan extends Date_Holidays_Driver
         $this->_buildGreeneryDay();
         $this->_buildChildrensDay();
         $this->_buildMarineDay();
+        $this->_buildMountainDay();
         $this->_buildRespectfortheAgedDay();
         $this->_buildAutumnalEquinoxDay();
         $this->_buildHealthandSportsDay();
@@ -373,6 +374,25 @@ class Date_Holidays_Driver_Japan extends Date_Holidays_Driver
         }
     }
 
+    /**
+     * build day of Mountain Day
+     *
+     * @access   private
+     * @return   void
+     */
+    function _buildMountainDay()
+    {
+        $date = null;
+        if ($this->_year >= 2016) {
+            $date = $this->_year . '-08-11';
+        }
+        if (!is_null($date)) {
+            $this->_addHoliday('mountainDay',
+                               $date,
+                               'Mountain Day');
+        }
+    }
+
     /**
      * build day of Respect for the Aged Day
      *
