@@ -9,16 +9,12 @@
  * @package  Date_Holidays
  * @author   Hideyuki Shimooka <shimooka@doyouphp.jp>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Date_Holidays_Driver_Japan_TestSuite.php 282411 2009-06-19 02:02:06Z shimooka $
+ * @version  CVS: $Id$
  * @link     http://pear.php.net/package/Date_Holidays
  */
-if (!defined("PHPUnit_MAIN_METHOD")) {
-    define("PHPUnit_MAIN_METHOD", "Date_HolidaysTest::main");
-}
 
-require_once 'Date/Holidays.php';
-
-define('LANG_FILE', '/usr/local/lib/php5/pear/data/Date_Holidays_Japan/lang/');
+/** Set up the environment */
+require_once dirname(__FILE__) . '/helper.inc';
 
 /**
  * Test class for running unit tests related to the driver for holidays
@@ -29,12 +25,13 @@ define('LANG_FILE', '/usr/local/lib/php5/pear/data/Date_Holidays_Japan/lang/');
  * @package  Date_Holidays
  * @author   Hideyuki Shimooka <shimooka@doyouphp.jp>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Date_Holidays_Driver_Japan_TestSuite.php 282411 2009-06-19 02:02:06Z shimooka $
+ * @version  CVS: $Id$
  * @link     http://pear.php.net/package/Date_Holidays
  */
 class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
 {
     var $_holidays;
+    protected $lang_dir;
 
     /**
      * setUp
@@ -44,6 +41,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
      */
     function setUp()
     {
+        $this->lang_dir = helper_get_lang_dir('Date_Holidays_Japan');
         $this->_holidays = array(
             '1970-01-01' => true,
             '1970-01-15' => true,
@@ -756,6 +754,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2016-05-04' => true,
             '2016-05-05' => true,
             '2016-07-18' => true,
+            '2016-08-11' => true,
             '2016-09-19' => true,
             '2016-09-22' => true,
             '2016-10-10' => true,
@@ -772,6 +771,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2017-05-04' => true,
             '2017-05-05' => true,
             '2017-07-17' => true,
+            '2017-08-11' => true,
             '2017-09-18' => true,
             '2017-09-23' => true,
             '2017-10-09' => true,
@@ -789,6 +789,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2018-05-04' => true,
             '2018-05-05' => true,
             '2018-07-16' => true,
+            '2018-08-11' => true,
             '2018-09-17' => true,
             '2018-09-23' => true,
             '2018-09-24' => true,
@@ -807,6 +808,8 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2019-05-05' => true,
             '2019-05-06' => true,
             '2019-07-15' => true,
+            '2019-08-11' => true,
+            '2019-08-12' => true,
             '2019-09-16' => true,
             '2019-09-23' => true,
             '2019-10-14' => true,
@@ -824,6 +827,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2020-05-05' => true,
             '2020-05-06' => true,
             '2020-07-20' => true,
+            '2020-08-11' => true,
             '2020-09-21' => true,
             '2020-09-22' => true,
             '2020-10-12' => true,
@@ -839,6 +843,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2021-05-04' => true,
             '2021-05-05' => true,
             '2021-07-19' => true,
+            '2021-08-11' => true,
             '2021-09-20' => true,
             '2021-09-23' => true,
             '2021-10-11' => true,
@@ -854,6 +859,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2022-05-04' => true,
             '2022-05-05' => true,
             '2022-07-18' => true,
+            '2022-08-11' => true,
             '2022-09-19' => true,
             '2022-09-23' => true,
             '2022-10-10' => true,
@@ -870,6 +876,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2023-05-04' => true,
             '2023-05-05' => true,
             '2023-07-17' => true,
+            '2023-08-11' => true,
             '2023-09-18' => true,
             '2023-09-23' => true,
             '2023-10-09' => true,
@@ -887,6 +894,8 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2024-05-05' => true,
             '2024-05-06' => true,
             '2024-07-15' => true,
+            '2024-08-11' => true,
+            '2024-08-12' => true,
             '2024-09-16' => true,
             '2024-09-22' => true,
             '2024-09-23' => true,
@@ -905,6 +914,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2025-05-05' => true,
             '2025-05-06' => true,
             '2025-07-21' => true,
+            '2025-08-11' => true,
             '2025-09-15' => true,
             '2025-09-23' => true,
             '2025-10-13' => true,
@@ -922,6 +932,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2026-05-05' => true,
             '2026-05-06' => true,
             '2026-07-20' => true,
+            '2026-08-11' => true,
             '2026-09-21' => true,
             '2026-09-22' => true,
             '2026-09-23' => true,
@@ -939,6 +950,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2027-05-04' => true,
             '2027-05-05' => true,
             '2027-07-19' => true,
+            '2027-08-11' => true,
             '2027-09-20' => true,
             '2027-09-23' => true,
             '2027-10-11' => true,
@@ -954,6 +966,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2028-05-04' => true,
             '2028-05-05' => true,
             '2028-07-17' => true,
+            '2028-08-11' => true,
             '2028-09-18' => true,
             '2028-09-22' => true,
             '2028-10-09' => true,
@@ -971,6 +984,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2029-05-04' => true,
             '2029-05-05' => true,
             '2029-07-16' => true,
+            '2029-08-11' => true,
             '2029-09-17' => true,
             '2029-09-23' => true,
             '2029-09-24' => true,
@@ -989,6 +1003,8 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2030-05-05' => true,
             '2030-05-06' => true,
             '2030-07-15' => true,
+            '2030-08-11' => true,
+            '2030-08-12' => true,
             '2030-09-16' => true,
             '2030-09-23' => true,
             '2030-10-14' => true,
@@ -1006,6 +1022,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2031-05-05' => true,
             '2031-05-06' => true,
             '2031-07-21' => true,
+            '2031-08-11' => true,
             '2031-09-15' => true,
             '2031-09-23' => true,
             '2031-10-13' => true,
@@ -1022,6 +1039,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2032-05-04' => true,
             '2032-05-05' => true,
             '2032-07-19' => true,
+            '2032-08-11' => true,
             '2032-09-20' => true,
             '2032-09-21' => true,
             '2032-09-22' => true,
@@ -1039,6 +1057,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2033-05-04' => true,
             '2033-05-05' => true,
             '2033-07-18' => true,
+            '2033-08-11' => true,
             '2033-09-19' => true,
             '2033-09-23' => true,
             '2033-10-10' => true,
@@ -1055,6 +1074,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2034-05-04' => true,
             '2034-05-05' => true,
             '2034-07-17' => true,
+            '2034-08-11' => true,
             '2034-09-18' => true,
             '2034-09-23' => true,
             '2034-10-09' => true,
@@ -1072,6 +1092,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2035-05-04' => true,
             '2035-05-05' => true,
             '2035-07-16' => true,
+            '2035-08-11' => true,
             '2035-09-17' => true,
             '2035-09-23' => true,
             '2035-09-24' => true,
@@ -1090,6 +1111,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2036-05-05' => true,
             '2036-05-06' => true,
             '2036-07-21' => true,
+            '2036-08-11' => true,
             '2036-09-15' => true,
             '2036-09-22' => true,
             '2036-10-13' => true,
@@ -1107,6 +1129,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2037-05-05' => true,
             '2037-05-06' => true,
             '2037-07-20' => true,
+            '2037-08-11' => true,
             '2037-09-21' => true,
             '2037-09-22' => true,
             '2037-09-23' => true,
@@ -1123,6 +1146,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2038-05-04' => true,
             '2038-05-05' => true,
             '2038-07-19' => true,
+            '2038-08-11' => true,
             '2038-09-20' => true,
             '2038-09-23' => true,
             '2038-10-11' => true,
@@ -1138,6 +1162,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2039-05-04' => true,
             '2039-05-05' => true,
             '2039-07-18' => true,
+            '2039-08-11' => true,
             '2039-09-19' => true,
             '2039-09-23' => true,
             '2039-10-10' => true,
@@ -1155,6 +1180,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2040-05-04' => true,
             '2040-05-05' => true,
             '2040-07-16' => true,
+            '2040-08-11' => true,
             '2040-09-17' => true,
             '2040-09-22' => true,
             '2040-10-08' => true,
@@ -1172,6 +1198,8 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2041-05-05' => true,
             '2041-05-06' => true,
             '2041-07-15' => true,
+            '2041-08-11' => true,
+            '2041-08-12' => true,
             '2041-09-16' => true,
             '2041-09-23' => true,
             '2041-10-14' => true,
@@ -1189,6 +1217,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2042-05-05' => true,
             '2042-05-06' => true,
             '2042-07-21' => true,
+            '2042-08-11' => true,
             '2042-09-15' => true,
             '2042-09-23' => true,
             '2042-10-13' => true,
@@ -1206,6 +1235,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2043-05-05' => true,
             '2043-05-06' => true,
             '2043-07-20' => true,
+            '2043-08-11' => true,
             '2043-09-21' => true,
             '2043-09-22' => true,
             '2043-09-23' => true,
@@ -1223,6 +1253,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2044-05-04' => true,
             '2044-05-05' => true,
             '2044-07-18' => true,
+            '2044-08-11' => true,
             '2044-09-19' => true,
             '2044-09-22' => true,
             '2044-10-10' => true,
@@ -1239,6 +1270,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2045-05-04' => true,
             '2045-05-05' => true,
             '2045-07-17' => true,
+            '2045-08-11' => true,
             '2045-09-18' => true,
             '2045-09-22' => true,
             '2045-10-09' => true,
@@ -1256,6 +1288,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2046-05-04' => true,
             '2046-05-05' => true,
             '2046-07-16' => true,
+            '2046-08-11' => true,
             '2046-09-17' => true,
             '2046-09-23' => true,
             '2046-09-24' => true,
@@ -1274,6 +1307,8 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2047-05-05' => true,
             '2047-05-06' => true,
             '2047-07-15' => true,
+            '2047-08-11' => true,
+            '2047-08-12' => true,
             '2047-09-16' => true,
             '2047-09-23' => true,
             '2047-10-14' => true,
@@ -1291,6 +1326,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2048-05-05' => true,
             '2048-05-06' => true,
             '2048-07-20' => true,
+            '2048-08-11' => true,
             '2048-09-21' => true,
             '2048-09-22' => true,
             '2048-10-12' => true,
@@ -1306,6 +1342,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2049-05-04' => true,
             '2049-05-05' => true,
             '2049-07-19' => true,
+            '2049-08-11' => true,
             '2049-09-20' => true,
             '2049-09-21' => true,
             '2049-09-22' => true,
@@ -1323,6 +1360,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
             '2050-05-04' => true,
             '2050-05-05' => true,
             '2050-07-18' => true,
+            '2050-08-11' => true,
             '2050-09-19' => true,
             '2050-09-23' => true,
             '2050-10-10' => true,
@@ -1343,7 +1381,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
         for ($year = 1970; $year < 2051; $year++) {
             $obj =& Date_Holidays::factory('Japan', $year);
             if (Date_Holidays::isError($obj)) {
-                $this->fail('Factory was unable to produce driver-object');
+                $this->fail(helper_get_error_message($obj));
             }
 
             $invalid_holidays = array();
@@ -1373,7 +1411,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
     {
         $obj = Date_Holidays::factory('Japan', 2008);
         if (Date_Holidays::isError($obj)) {
-            $this->fail('Factory was unable to produce driver-object');
+            $this->fail(helper_get_error_message($obj));
         }
         // calculate substitute holiday for Children's Day (1st time)
         $this->assertTrue($obj->isHoliday(new Date('2008-05-06')), '1st time');
@@ -1397,9 +1435,9 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
         // with ja_JP.xml
         $obj = Date_Holidays::factory('Japan', 2008);
         if (Date_Holidays::isError($obj)) {
-            $this->fail('Factory was unable to produce driver-object');
+            $this->fail(helper_get_error_message($obj));
         }
-        $obj->addTranslationFile(LANG_FILE . '/Japan/ja_JP.xml', 'ja_JP');
+        $obj->addTranslationFile($this->lang_dir . '/Japan/ja_JP.xml', 'ja_JP');
         if (Date_Holidays::isError($obj)) {
             $this->fail('fail to add translation file');
         }
@@ -1424,9 +1462,9 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
         // with ja_JP.ser
         $obj = Date_Holidays::factory('Japan', 2008);
         if (Date_Holidays::isError($obj)) {
-            $this->fail('Factory was unable to produce driver-object');
+            $this->fail(helper_get_error_message($obj));
         }
-        $obj->addCompiledTranslationFile(LANG_FILE . '/Japan/ja_JP.ser', 'ja_JP');
+        $obj->addCompiledTranslationFile($this->lang_dir . '/Japan/ja_JP.ser', 'ja_JP');
         if (Date_Holidays::isError($obj)) {
             $this->fail('fail to add translation file');
         }
@@ -1451,7 +1489,7 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
     {
         $obj =& Date_Holidays::factory('Japan');
         if (Date_Holidays::isError($obj)) {
-            $this->fail('Factory was unable to produce driver-object');
+            $this->fail(helper_get_error_message($obj));
         }
         for ($year = 1970; $year < 2051; $year++) {
             $obj->setYear($year);
@@ -1483,9 +1521,9 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
         // with ja_JP.xml
         $obj = Date_Holidays::factory('Japan', 1949);
         if (Date_Holidays::isError($obj)) {
-            $this->fail('Factory was unable to produce driver-object');
+            $this->fail(helper_get_error_message($obj));
         }
-        $obj->addTranslationFile(LANG_FILE . '/Japan/ja_JP.xml', 'ja_JP');
+        $obj->addTranslationFile($this->lang_dir . '/Japan/ja_JP.xml', 'ja_JP');
         if (Date_Holidays::isError($obj)) {
             $this->fail('fail to add translation file');
         }
@@ -1510,9 +1548,9 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
         // with ja_JP.ser
         $obj = Date_Holidays::factory('Japan', 1949);
         if (Date_Holidays::isError($obj)) {
-            $this->fail('Factory was unable to produce driver-object');
+            $this->fail(helper_get_error_message($obj));
         }
-        $obj->addCompiledTranslationFile(LANG_FILE . '/Japan/ja_JP.ser', 'ja_JP');
+        $obj->addCompiledTranslationFile($this->lang_dir . '/Japan/ja_JP.ser', 'ja_JP');
         if (Date_Holidays::isError($obj)) {
             $this->fail('fail to add translation file');
         }
@@ -1537,9 +1575,9 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
         // with ja_JP.xml
         $obj = Date_Holidays::factory('Japan', 1986);
         if (Date_Holidays::isError($obj)) {
-            $this->fail('Factory was unable to produce driver-object');
+            $this->fail(helper_get_error_message($obj));
         }
-        $obj->addTranslationFile(LANG_FILE . '/Japan/ja_JP.xml', 'ja_JP');
+        $obj->addTranslationFile($this->lang_dir . '/Japan/ja_JP.xml', 'ja_JP');
         if (Date_Holidays::isError($obj)) {
             $this->fail('fail to add translation file');
         }
@@ -1565,9 +1603,9 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
         // with ja_JP.ser
         $obj = Date_Holidays::factory('Japan', 1986);
         if (Date_Holidays::isError($obj)) {
-            $this->fail('Factory was unable to produce driver-object');
+            $this->fail(helper_get_error_message($obj));
         }
-        $obj->addCompiledTranslationFile(LANG_FILE . '/Japan/ja_JP.ser', 'ja_JP');
+        $obj->addCompiledTranslationFile($this->lang_dir . '/Japan/ja_JP.ser', 'ja_JP');
         if (Date_Holidays::isError($obj)) {
             $this->fail('fail to add translation file');
         }
@@ -1593,16 +1631,16 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
         for ($year = 1900; $year < date('Y'); $year++) {
             $obj = Date_Holidays::factory('Japan', $year, 'ja_JP');
             if (Date_Holidays::isError($obj)) {
-                $this->fail('Factory was unable to produce driver-object');
+                $this->fail(helper_get_error_message($obj));
             }
-            $obj->addTranslationFile(LANG_FILE . '/Japan/ja_JP.xml', 'ja_JP');
-            if (Date_Holidays::isError($obj)) {
-                $this->fail('fail to add translation file');
+            $res = $obj->addTranslationFile($this->lang_dir . '/Japan/ja_JP.xml', 'ja_JP');
+            if (Date_Holidays::isError($res)) {
+                $this->fail(helper_get_error_message($res));
             }
             $holidays = array();
             foreach ($obj->getHolidays() as $h) {
                 if (PEAR::isError($h)) {
-                    $this->fail('test failed');
+                    $this->fail(helper_get_error_message($h));
                 }
                 $holidays[$h->getDate()->format('%Y-%m-%d')] = $h->getTitle();
             }
